<?php
/*
// Parseur PHP avec cURL pour récupérer les contenus de Facebook
// Créateur : Mathieu Chartier
// Version : 1.0
// Date : 15/07/2014
*/
function parserFacebook($idPage = '', $nb = 5, $keepImg = false) {
	// URL de Facebook
	$url = "https://www.facebook.com/feeds/page.php?id=";
	$url.= $idPage;
	$url.= "&format=rss20"; // ou "json" ou "atom10"

	// Lancement de cURL
	$curl = curl_init($url);

	// Ajout d'entêtes pour se faire passer pour un robot
	$header = array(
		"Accept: text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5",
		"Cache-Control: max-age=0",
		"Accept-Charset: UTF-8;q=0.7,*;q=0.7",
		"Pragma: " // Pas de cache par défaut
	);
	
	// User-agent automatique (au pire, en choisir un précis)
	$ua = $_SERVER['HTTP_USER_AGENT'];
	
	// URL referer à renvoyer à Facebook (vide recommandé !)
	$referer = "";
	
	// Timeout de cURL
	$timeout = 30;
	
	// Options de cURL
	curl_setopt($curl, CURLOPT_USERAGENT, $ua);
	curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
	curl_setopt($curl, CURLOPT_REFERER, $referer);
	curl_setopt($curl, CURLOPT_AUTOREFERER, true);
	curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
	curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, $timeout);
	curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);

	// Exécution de cURL
	$cURLxml = curl_exec($curl);

	// Fermeture de cURL
	curl_close($curl);

	// Récupération des données XML avec simpleXML
	$simpleXML = simplexml_load_string($cURLxml);
	$simpleXML = $simpleXML->channel->item;

	// Conservation uniquement des posts réels
	foreach($simpleXML as $item) {
		$verif = preg_match("#(/posts/|/photos/|permalink)#iU", $item->link);
		if($verif == true) {
			$tabItem[] = $item;
		}
	}

	// Instanciation des variables par défaut
	$resultat = '';
	$i = 0;
	
	// Boucle de récupération des résultats
	foreach($tabItem as $item) {
		// Instanciation des variables
		$urlPage= "https://www.facebook.com/".$idPage;
		$date	= date("d/m/Y à h:i:s", strtotime($item->pubDate));
		$auteur	= $item->author;
		$lien	= $item->link;
		$titre	= trim($item->title);
		$texte	= trim($item->description);
		
		// Tant que le nombre de résultats correspond à nos souhaits
		if($i < $nb) {
			// Supprime les sauts de ligne inutiles
			$regex = '#(<br(/?)>)+(<a(.*)>(.*)</a>)(<br(/?)>)?#iU';
			$texte = preg_replace($regex, '$3', $texte);
			$regex = '#(<br(/?)>){2,}#iU';
			$texte = preg_replace($regex, '<br/>', $texte);

			// On supprime les images si on ne veut garder que le texte
			if($keepImg == false) {
				$regex = '#(<a(.*)><img(.*)></a>)#iU';
				$texte = preg_replace($regex, '', $texte);
			} else {
				$regex = '#(<a(.*)><img(.*)></a>)#iU';
				$texte = preg_replace($regex, '<p>$1<p>', $texte);
			}

			// Suppression du titre répété dans le texte...
			$texte = str_ireplace($titre, '', $texte);

			// Formatage du résultat
			$resultat .= '<div class="block">';
			$resultat .= '<h3 class="titre"><a href="'.$lien.'" target="_blank">'.$titre.'</a></h3>';
			$resultat .= '<div class="meta">Publié le '.$date.' par <a href="'.$urlPage.'" target="_blank">'.$auteur.'</a></div>';
			$resultat .= '<div class="contenu">'.$texte.'</div>';
			$resultat .= '</div>';
		} else {
			break;
		}

		// Incrémentation
		$i++;
	}
	
	// Retourne le résultat final
	return $resultat;
}
?>
<!DOCTYPE html>
<html>
<head>
<meta charset="utf-8"/>
<title>Parseur Facebook</title>
<style type="text/css"/>
* {margin:0; padding:0; font-size:100%}
#formulaire {background:#f5f5f5; padding:1em; border-bottom:1px solid #999;}
#formulaire h1 {font-size:1.8em; color:#3b5998; margin-bottom:1em}
.bloc {margin-bottom:.8em}
.bloc label {display:block; font-weight:bold; padding:.1em;}
.bloc input, .bloc select {display:block; float:left; margin-right:1em; padding:.1em; border:1px solid #999;}
.bloc input {width:200px;}
.bloc select {width:72px; text-align:center;}
#resultat {padding:1em}
#resultat h2 {font-size:1.3em; color:#3b5998; margin-bottom:.8em}
#bouton input {padding:.2em .5em; font-weight:bold; border:1px solid #999; background:#fff; color:#3b5998}
#bouton input:hover {background:#3b5998; color:#fff}
.block {margin-bottom:1em; border:1px solid #999; padding:1em}
.block a {color:#3b5998}
.block .meta {font-size:.7em; color:#999}
.block .contenu {font-size:.8em; padding-top:.5em}
</style>
</head>

<body>
<div id="formulaire">
	<h1>Parseur XML pour des pages Facebook</h1>
	<form method="post">
		<div class="bloc">
		<input type="text" name="url" value="<?php if(isset($_POST['url'])) { echo $_POST['url']; } ?>"/>
		<label for="url">ID de la page Facebook</label>
		</div>
		
		<div class="bloc">
		<select name="nb">
			<?php
				for($i = 1; $i < 11; $i++) {
			?>
			<option value="<?php echo $i; ?>" <?php if(isset($_POST['nb']) && $_POST['nb'] == $i) { echo 'selected="selected"'; } ?>><?php echo $i; ?></option>
			<?php
				}
			?>
		</select>
		<label for="nb">Nombre de publications à afficher</label>
		</div>

		<div class="bloc">
		<select name="img">
			<option value="0" <?php if(isset($_POST['img']) && $_POST['img'] == 0) { echo 'selected="selected"'; } ?>>Non</option>
			<option value="1" <?php if(isset($_POST['img']) && $_POST['img'] == 1) { echo 'selected="selected"'; } ?>>Oui</option>
		</select>
		<label for="img">Conserver les images dans les publications ?</label>
		</div>
		
		<p id="bouton"><input type="submit" name="submit" value="Afficher"/></p>
	</form>
</div>
	
<div id="resultat">
	<?php if(isset($_POST['submit']) && !empty($_POST['url'])) {	?>
	<?php // Traitement des données
		$url	= htmlspecialchars($_POST['url']);
		$nb		= htmlspecialchars($_POST['nb']);
		$img	= htmlspecialchars($_POST['img']);
	?>
	<h2>Affichage des dernières publications Facebook</h2>
	<p><?php echo parserFacebook($url, $nb, $img); ?></p>
	<?php } ?>
</div>
</body>
</html>